Kerttula
========

`Kerttula` is a home automation application built on top of 'Juham' framework.
It controls my home.


Project Status
--------------

**Current State**: **Pre-Alpha (Status 2)**  
In its current form, Kerttula™ may still resemble more of a distant mission (or even a "mess") than a "masterpiece," but I'm actively developing it to reach that goal!

Please check out the `CHANGELOG <CHANGELOG.rst>`_ file for changes in this release.


Installation
------------

The installation is two stage process

1. To install:

.. code-block:: python

    pip install kerttula


2. Configure

   OpenWeatherMap and various other services require you to register and obtain web keys and things like
   that. Most importantly, Influx DB and Graphana cloud accounts must be created for data visualization.
   Please consult 'juham' documentation for more information.



License
-------

This project is licensed under the MIT License - see the `LICENSE <LICENSE.rst>`_ file.

